// src/startup/renderer.tsx
import { Pool as Pool3, Startup } from "pr1";
import { Component as Component8 } from "react";
import { createRoot } from "react-dom/client";

// node_modules/seq-ord/lib/index.js
function binary(a, b) {
  if (!a && b)
    return -1;
  if (a && !b)
    return 1;
  return 0;
}
function date(a, b) {
  return numeric(a.getTime(), b.getTime());
}
function numeric(a, b) {
  return a - b;
}
function text(a, b, locales, options) {
  return a.localeCompare(b, locales, options);
}
function textCodepoint(a, b) {
  if (a < b)
    return -1;
  if (a > b)
    return 1;
  return 0;
}
function binaryExt(cmpFF, cmpTT) {
  return (a, b) => {
    let value = binary(a, b);
    return value === 0 ? a && b ? cmpTT() : cmpFF() : value;
  };
}
function sequence(generator, that) {
  return (a, b) => {
    let iterator = generator.call(that, a, b, Rules);
    for (let value of iterator) {
      if (value) {
        return value;
      }
    }
    return 0;
  };
}
var lib_default = sequence;
var Rules = {
  binary,
  date,
  numeric,
  text,
  textCodepoint,
  binaryExt,
  sequence
};

// src/shared/context-menu.tsx
import { ContextMenuContext, React } from "pr1";
import { jsx } from "react/jsx-runtime";
var NativeContextMenu = class extends React.Component {
  constructor(props) {
    super(props);
    this.props.triggerRef.current = (event) => {
      let menu = this.props.createMenu(event);
      let position = {
        x: event.clientX,
        y: event.clientY
      };
      window.api.main.triggerContextMenu(menu, position).then((selectedPath) => {
        if (selectedPath !== null) {
          this.props.onSelect(selectedPath);
        }
        this.props.onClose(selectedPath !== null);
      });
    };
  }
  render() {
    return null;
  }
};
function NativeContextMenuProvider(props) {
  return /* @__PURE__ */ jsx(ContextMenuContext.Provider, { value: NativeContextMenu, children: props.children });
}

// src/startup/host-creator.tsx
import { Pool as Pool2, React as React7 } from "pr1";

// src/startup/steps/s0.tsx
import { Form, React as React2 } from "pr1";
import { jsx as jsx2, jsxs } from "react/jsx-runtime";
function Component(props) {
  let firstInputRef = React2.createRef();
  React2.useEffect(() => {
    firstInputRef.current.focus();
  }, []);
  return /* @__PURE__ */ jsxs("form", { className: "startup-editor-contents", onSubmit: (event) => {
    event.preventDefault();
    props.setData({
      stepIndex: 1,
      options: {
        fingerprint: null,
        hostname: props.data.hostname,
        identifier: null,
        password: null,
        port: parseInt(props.data.port),
        secure: props.data.secure,
        trusted: false
      },
      previousStepData: props.data
    });
  }, children: [
    /* @__PURE__ */ jsxs("div", { className: "startup-editor-inner", children: [
      /* @__PURE__ */ jsxs("header", { className: "startup-editor-header", children: [
        /* @__PURE__ */ jsx2("div", { className: "startup-editor-subtitle", children: "New setup" }),
        /* @__PURE__ */ jsx2("h2", { children: "Set connection parameters" })
      ] }),
      /* @__PURE__ */ jsxs(Form.Form, { children: [
        /* @__PURE__ */ jsx2(
          Form.Select,
          {
            label: "Protocol",
            onInput: (protocol) => void props.setData({ ...props.data, secure: protocol === "secure-tcp" }),
            options: [
              { id: "secure-tcp", label: "TCP with TLS" },
              { id: "unsecure-tcp", label: "TCP" }
            ],
            value: props.data.secure ? "secure-tcp" : "unsecure-tcp",
            targetRef: firstInputRef
          }
        ),
        /* @__PURE__ */ jsx2(
          Form.TextField,
          {
            label: "Address",
            onInput: (address) => void props.setData({ ...props.data, hostname: address }),
            placeholder: "e.g. 192.168.1.143",
            value: props.data.hostname
          }
        ),
        /* @__PURE__ */ jsx2(
          Form.TextField,
          {
            label: "Port",
            onInput: (port) => void props.setData({ ...props.data, port }),
            placeholder: "e.g. 4567",
            value: props.data.port
          }
        )
      ] })
    ] }),
    /* @__PURE__ */ jsxs("div", { className: "startup-editor-action-root", children: [
      /* @__PURE__ */ jsx2("div", { className: "startup-editor-action-list", children: /* @__PURE__ */ jsx2("button", { type: "button", className: "startup-editor-action-item", onClick: () => {
        props.setData({ stepIndex: 4, mode: "remote" });
      }, children: "Back" }) }),
      /* @__PURE__ */ jsxs("div", { className: "startup-editor-action-list", children: [
        /* @__PURE__ */ jsx2("button", { type: "button", className: "startup-editor-action-item", onClick: () => {
          props.setData({
            stepIndex: 7,
            previousStepData: props.data,
            selectedHostIdentifier: null
          });
        }, children: "Search for setups on this network" }),
        /* @__PURE__ */ jsx2("button", { type: "submit", className: "startup-editor-action-item", children: "Next" })
      ] })
    ] })
  ] });
}

// src/startup/steps/s1.tsx
import { Form as Form2, LargeIcon, React as React3, util } from "pr1";
import { Fragment, jsx as jsx3, jsxs as jsxs2 } from "react/jsx-runtime";
function Component2(props) {
  let pool = util.usePool();
  let [attempt, setAttempt] = React3.useState(0);
  let [result, setResult] = React3.useState(null);
  let [label, setLabel] = React3.useState("");
  let [password, setPassword] = React3.useState("");
  let targetRef = React3.useCallback((el) => {
    if (el instanceof HTMLInputElement) {
      el.select();
    } else if (el instanceof HTMLElement) {
      el.focus();
    }
  }, []);
  React3.useEffect(() => {
    pool.add(async () => {
      let result2 = await window.api.hostSettings.testRemoteHost({
        fingerprint: null,
        hostname: props.data.options.hostname,
        identifier: props.data.options.identifier,
        password: props.data.options.password,
        port: props.data.options.port,
        secure: props.data.options.secure,
        trusted: props.data.options.trusted
      });
      setResult(result2);
      if ("fingerprint" in result2) {
        let fingerprint = result2.fingerprint;
        props.setData((data) => ({
          options: {
            ...data.options,
            fingerprint
          }
        }));
      }
      if ("identifier" in result2) {
        let identifier = result2.identifier;
        props.setData((data) => ({
          options: {
            ...data.options,
            identifier
          }
        }));
      }
      if (result2.ok) {
        setLabel(result2.name);
      } else if (result2.reason === "missing_password") {
        setPassword("");
      }
    });
  }, [
    attempt,
    props.data.options.trusted
  ]);
  return /* @__PURE__ */ jsxs2("form", { className: "startup-editor-contents", onSubmit: (event) => {
    event.preventDefault();
    if (result?.ok) {
      setResult(null);
      pool.add(async () => {
        let trimmedLabel = label.trim();
        let result2 = await window.api.hostSettings.addRemoteHost({
          options: props.data.options,
          label: trimmedLabel
        });
        await props.queryHostSettings();
        props.setData({
          stepIndex: 2,
          hostSettingsId: result2.hostSettingsId,
          label: trimmedLabel
        });
      });
      return;
    }
    switch (result.reason) {
      case "missing_password": {
        setResult(null);
        props.setData((data) => ({
          options: {
            ...data.options,
            password
          }
        }));
        break;
      }
      case "untrusted_server": {
        setResult(null);
        props.setData((data) => ({
          options: {
            ...data.options,
            trusted: true
          }
        }));
        break;
      }
    }
  }, children: [
    /* @__PURE__ */ jsxs2("div", { className: "startup-editor-inner", children: [
      /* @__PURE__ */ jsxs2("header", { className: "startup-editor-header", children: [
        /* @__PURE__ */ jsx3("div", { className: "startup-editor-subtitle", children: "New setup" }),
        /* @__PURE__ */ jsx3("h2", { children: "Set connection parameters" })
      ] }),
      result ? (() => {
        if (result.ok) {
          return /* @__PURE__ */ jsx3("div", { children: /* @__PURE__ */ jsx3(
            Form2.TextField,
            {
              label: "Setup name",
              onInput: (value) => void setLabel(value),
              value: label,
              targetRef
            }
          ) });
        }
        switch (result.reason) {
          case "invalid_parameters":
            return /* @__PURE__ */ jsxs2("div", { className: "startup-editor-status", children: [
              /* @__PURE__ */ jsx3(LargeIcon, { name: "error" }),
              /* @__PURE__ */ jsx3("p", { children: "Invalid parameters" })
            ] });
          case "missing_password":
            return /* @__PURE__ */ jsx3("div", { children: /* @__PURE__ */ jsx3(
              Form2.TextField,
              {
                label: "Password",
                onInput: (value) => void setPassword(value),
                value: password,
                targetRef
              }
            ) });
          case "refused":
            return /* @__PURE__ */ jsxs2("div", { className: "startup-editor-status", children: [
              /* @__PURE__ */ jsx3(LargeIcon, { name: "error" }),
              /* @__PURE__ */ jsx3("p", { children: "Connection refused" })
            ] });
          case "unauthorized":
            return /* @__PURE__ */ jsxs2("div", { className: "startup-editor-status", children: [
              /* @__PURE__ */ jsx3(LargeIcon, { name: "error" }),
              /* @__PURE__ */ jsxs2("p", { children: [
                "Unauthorized: ",
                result.message
              ] })
            ] });
          case "untrusted_server":
            return /* @__PURE__ */ jsxs2("div", { className: "startup-editor-status", children: [
              /* @__PURE__ */ jsx3(LargeIcon, { name: "question" }),
              /* @__PURE__ */ jsxs2("p", { children: [
                "Trust certificate with fingerprint ",
                formatHex(result.fingerprint.slice(0, 20)),
                "...?"
              ] })
            ] });
          default:
            return /* @__PURE__ */ jsxs2("div", { className: "startup-editor-status", children: [
              /* @__PURE__ */ jsx3(LargeIcon, { name: "error" }),
              /* @__PURE__ */ jsx3("p", { children: "Internal error" })
            ] });
        }
      })() : /* @__PURE__ */ jsx3("div", { className: "startup-editor-status", children: /* @__PURE__ */ jsx3("p", { children: "Loading" }) })
    ] }),
    /* @__PURE__ */ jsxs2("div", { className: "startup-editor-action-root", children: [
      /* @__PURE__ */ jsx3("div", { className: "startup-editor-action-list", children: /* @__PURE__ */ jsx3("button", { type: "button", className: "startup-editor-action-item", onClick: () => {
        props.setData(props.data.previousStepData);
      }, children: "Back" }) }),
      /* @__PURE__ */ jsx3("div", { className: "startup-editor-action-list", children: result && (() => {
        if (result.ok) {
          return /* @__PURE__ */ jsx3("button", { type: "submit", className: "startup-editor-action-item", disabled: label.trim().length < 1, children: "Finish" });
        }
        switch (result.reason) {
          case "missing_password":
            return /* @__PURE__ */ jsx3("button", { type: "submit", className: "startup-editor-action-item", children: "Next" });
          case "refused":
            return /* @__PURE__ */ jsx3("button", { type: "button", className: "startup-editor-action-item", onClick: () => {
              setResult(null);
              setAttempt(attempt + 1);
            }, children: "Retry" });
          case "untrusted_server":
            return /* @__PURE__ */ jsxs2(Fragment, { children: [
              /* @__PURE__ */ jsx3("button", { type: "button", className: "startup-editor-action-item", onClick: () => {
                pool.add(async () => {
                  let options = props.data.options;
                  await window.api.hostSettings.displayCertificateOfRemoteHost({
                    fingerprint: options.fingerprint,
                    hostname: options.hostname,
                    port: options.port
                  });
                });
              }, children: "Show certificate" }),
              /* @__PURE__ */ jsx3("button", { type: "submit", className: "startup-editor-action-item", ref: targetRef, children: "Trust" })
            ] });
          default:
            return null;
        }
      })() })
    ] })
  ] });
}
function formatHex(input) {
  let chars = input.toUpperCase().split("");
  return new Array(chars.length / 2).fill(0).map((_, index) => chars[index * 2] + chars[index * 2 + 1]).join(":");
}

// src/startup/steps/s2.tsx
import { LargeIcon as LargeIcon2 } from "pr1";
import { jsx as jsx4, jsxs as jsxs3 } from "react/jsx-runtime";
function Component3(props) {
  return /* @__PURE__ */ jsxs3("div", { className: "startup-editor-contents", children: [
    /* @__PURE__ */ jsxs3("div", { className: "startup-editor-inner", children: [
      /* @__PURE__ */ jsxs3("header", { className: "startup-editor-header", children: [
        /* @__PURE__ */ jsx4("div", { className: "startup-editor-subtitle", children: "New setup" }),
        /* @__PURE__ */ jsx4("h2", { children: "Set connection parameters" })
      ] }),
      /* @__PURE__ */ jsxs3("div", { className: "startup-editor-status", children: [
        /* @__PURE__ */ jsx4(LargeIcon2, { name: "success" }),
        /* @__PURE__ */ jsxs3("p", { children: [
          'Succesfully added "',
          props.data.label,
          '"'
        ] })
      ] })
    ] }),
    /* @__PURE__ */ jsxs3("div", { className: "startup-editor-action-root", children: [
      /* @__PURE__ */ jsx4("div", { className: "startup-editor-action-list", children: /* @__PURE__ */ jsx4("button", { type: "button", className: "startup-editor-action-item", onClick: () => {
        props.cancel();
      }, children: "Close" }) }),
      /* @__PURE__ */ jsx4("div", { className: "startup-editor-action-list", children: /* @__PURE__ */ jsx4("button", { type: "button", className: "startup-editor-action-item", onClick: () => {
        window.api.hostSettings.launchHost({ hostSettingsId: props.data.hostSettingsId });
      }, children: "Launch" }) })
    ] })
  ] });
}

// src/startup/steps/s4.tsx
import { Selector } from "pr1";
import { jsx as jsx5, jsxs as jsxs4 } from "react/jsx-runtime";
function Component4(props) {
  return /* @__PURE__ */ jsxs4("form", { className: "startup-editor-contents", onSubmit: (event) => {
    event.preventDefault();
    switch (props.data.mode) {
      case "advanced": {
        let pythonInstallations = Object.values(props.context.pythonInstallations);
        let pythonInstallationId = (pythonInstallations.find((pythonInstallation) => pythonInstallation.leaf) ?? pythonInstallations[0])?.id;
        props.setData({
          stepIndex: 5,
          customPythonInstallation: null,
          label: props.context.computerName,
          pythonInstallationSettings: null
        });
        break;
      }
      case "remote": {
        props.setData({
          stepIndex: 0,
          hostname: "",
          port: "",
          secure: true
        });
        break;
      }
    }
  }, children: [
    /* @__PURE__ */ jsxs4("div", { className: "startup-editor-inner", children: [
      /* @__PURE__ */ jsxs4("header", { className: "startup-editor-header", children: [
        /* @__PURE__ */ jsx5("div", { className: "startup-editor-subtitle", children: "New setup" }),
        /* @__PURE__ */ jsx5("h2", { children: "Select a setup configuration" })
      ] }),
      /* @__PURE__ */ jsx5(
        Selector,
        {
          entries: [
            {
              id: "automatic",
              name: "Default configuration",
              description: "Create a setup with default settings",
              icon: "local_shipping",
              disabled: true
            },
            {
              id: "advanced",
              name: "Advanced configuration",
              description: "Create a setup with advanced settings",
              icon: "architecture"
            },
            {
              id: "remote",
              name: "Remote setup",
              description: "Connect to an existing setup on this network",
              icon: "cloud"
            }
          ],
          onSelect: (mode) => void props.setData({ mode }),
          selectedEntryId: props.data.mode
        }
      )
    ] }),
    /* @__PURE__ */ jsxs4("div", { className: "startup-editor-action-root", children: [
      /* @__PURE__ */ jsx5("div", { className: "startup-editor-action-list", children: /* @__PURE__ */ jsx5("button", { type: "button", className: "startup-editor-action-item", onClick: () => void props.cancel(), children: "Cancel" }) }),
      /* @__PURE__ */ jsx5("div", { className: "startup-editor-action-list", children: /* @__PURE__ */ jsx5("button", { type: "submit", className: "startup-editor-action-item", disabled: !props.data.mode, children: "Next" }) })
    ] })
  ] });
}

// src/startup/steps/s5.tsx
import { Form as Form3 } from "pr1";
import { useCallback } from "react";
import { Fragment as Fragment2, jsx as jsx6, jsxs as jsxs5 } from "react/jsx-runtime";
function Component5(props) {
  let currentSettings = props.data.pythonInstallationSettings;
  let selectPythonInstallation = (selectedPythonInstallation) => {
    props.setData({
      ...props.data,
      customPythonInstallation: !(selectedPythonInstallation.id in props.context.pythonInstallations) ? selectedPythonInstallation : null,
      pythonInstallationSettings: {
        id: selectedPythonInstallation.id,
        architecture: currentSettings && selectedPythonInstallation.info.architectures && selectedPythonInstallation.info.architectures.includes(currentSettings.architecture) ? currentSettings.architecture : "_auto",
        virtualEnv: (currentSettings?.virtualEnv ?? true) && selectedPythonInstallation.info.supportsVirtualEnv || selectedPythonInstallation.info.isVirtualEnv
      }
    });
  };
  if (!currentSettings) {
    let selectedPythonInstallation = Object.values(props.context.pythonInstallations).find((pythonInstallation) => isPythonInstallationSupported(pythonInstallation));
    if (selectedPythonInstallation) {
      selectPythonInstallation(selectedPythonInstallation);
      return null;
    }
  }
  return /* @__PURE__ */ jsxs5("form", { className: "startup-editor-contents", onSubmit: (event) => {
    event.preventDefault();
    let installationSettings = currentSettings;
    let options = {
      customPythonInstallation: props.data.customPythonInstallation,
      label: props.data.label.trim(),
      pythonInstallationSettings: {
        architecture: installationSettings.architecture !== "_auto" ? installationSettings.architecture : null,
        id: installationSettings.id,
        virtualEnv: installationSettings.virtualEnv
      }
    };
    props.setData({
      stepIndex: 6,
      options
    });
  }, children: [
    /* @__PURE__ */ jsxs5("div", { className: "startup-editor-inner", children: [
      /* @__PURE__ */ jsxs5("header", { className: "startup-editor-header", children: [
        /* @__PURE__ */ jsx6("div", { className: "startup-editor-subtitle", children: "New setup" }),
        /* @__PURE__ */ jsx6("h2", { children: "Set parameters" })
      ] }),
      /* @__PURE__ */ jsxs5("div", { children: [
        /* @__PURE__ */ jsx6(
          Form3.TextField,
          {
            label: "Setup name",
            onInput: (label) => void props.setData({ ...props.data, label }),
            value: props.data.label,
            targetRef: useCallback((el) => void el?.select(), [])
          }
        ),
        /* @__PURE__ */ jsx6(
          Form3.Select,
          {
            label: "Python location",
            onInput: (optionId) => {
              (async () => {
                if (optionId === "_custom") {
                  let customPythonInstallation = await window.api.hostSettings.selectPythonInstallation();
                  if (customPythonInstallation) {
                    selectPythonInstallation(customPythonInstallation);
                  }
                } else {
                  selectPythonInstallation(props.context.pythonInstallations[optionId]);
                }
              })();
            },
            options: [
              ...!currentSettings ? [{ id: null, label: "Select a Python location\u2026" }] : [],
              { id: "_header.main", label: "[Common locations]", disabled: true },
              ...Object.values(props.context.pythonInstallations).filter((pythonInstallation) => pythonInstallation.leaf).sort(sortPythonInstallations).map(createSelectOptionFromPythonInstallation),
              { id: "_header.others", label: "[Other locations]", disabled: true },
              ...Object.values(props.context.pythonInstallations).filter((pythonInstallation) => !pythonInstallation.leaf).sort(sortPythonInstallations).map(createSelectOptionFromPythonInstallation),
              { id: "_header.custom", label: "[Custom locations]", disabled: true },
              ...props.data.customPythonInstallation ? [createSelectOptionFromPythonInstallation(props.data.customPythonInstallation)] : [],
              { id: "_custom", label: "Custom location" }
            ],
            value: currentSettings?.id ?? null
          }
        ),
        currentSettings && (() => {
          let currentPythonInstallation = props.data.customPythonInstallation ?? props.context.pythonInstallations[currentSettings.id];
          return /* @__PURE__ */ jsxs5(Fragment2, { children: [
            /* @__PURE__ */ jsx6(
              Form3.Select,
              {
                label: "Architecture",
                onInput: (architecture) => void props.setData({
                  ...props.data,
                  pythonInstallationSettings: {
                    ...currentSettings,
                    architecture
                  }
                }),
                options: [
                  { id: "_auto", label: "Automatic" },
                  ...currentPythonInstallation.info.architectures?.map((architecture) => ({
                    id: architecture,
                    label: architecture
                  })) ?? []
                ],
                value: currentSettings.architecture
              }
            ),
            /* @__PURE__ */ jsx6(Form3.CheckboxList, { label: "Virtual environment", children: /* @__PURE__ */ jsxs5(
              Form3.Checkbox,
              {
                checked: currentSettings.virtualEnv,
                disabled: currentPythonInstallation.info.isVirtualEnv || !currentPythonInstallation.info.supportsVirtualEnv,
                label: "Create a virtual environment",
                onInput: (value) => void props.setData({
                  ...props.data,
                  pythonInstallationSettings: {
                    ...currentSettings,
                    virtualEnv: value
                  }
                }),
                children: [
                  !currentPythonInstallation.info.supportsVirtualEnv && /* @__PURE__ */ jsx6("p", { children: "Virtual environments are not supported in this Python installation. Install venv to add their support." }),
                  currentPythonInstallation.info.isVirtualEnv && /* @__PURE__ */ jsx6("p", { children: "This installation is already a virtual environment." })
                ]
              }
            ) })
          ] });
        })()
      ] })
    ] }),
    /* @__PURE__ */ jsxs5("div", { className: "startup-editor-action-root", children: [
      /* @__PURE__ */ jsx6("div", { className: "startup-editor-action-list", children: /* @__PURE__ */ jsx6("button", { type: "button", className: "startup-editor-action-item", onClick: () => {
        props.setData({
          stepIndex: 4,
          mode: "advanced"
        });
      }, children: "Back" }) }),
      /* @__PURE__ */ jsx6("div", { className: "startup-editor-action-list", children: /* @__PURE__ */ jsx6("button", { type: "submit", className: "startup-editor-action-item", disabled: !currentSettings || !props.data.label.trim(), children: "Next" }) })
    ] })
  ] });
}
function createSelectOptionFromPythonInstallation(pythonInstallation) {
  let info = pythonInstallation.info;
  let supported = isPythonInstallationSupported(pythonInstallation);
  return {
    id: pythonInstallation.id,
    disabled: !supported,
    label: `${pythonInstallation.path} (${[
      info.version.join("."),
      ...info.isVirtualEnv ? ["virtual environment"] : []
    ].join(", ")})${supported ? "" : " \u2014 Not supported"}`
  };
}
function isPythonInstallationSupported(pythonInstallation) {
  let version = pythonInstallation.info.version;
  return version[0] === 3 && version[1] >= 11;
}
var sortPythonInstallations = lib_default(function* (a, b, rules) {
  yield rules.numeric(b.info.version[0], a.info.version[0]);
  yield rules.numeric(b.info.version[1], a.info.version[1]);
  yield rules.numeric(b.info.version[2], a.info.version[2]);
  yield rules.text(a.path, b.path);
});

// src/startup/steps/s6.tsx
import { LargeIcon as LargeIcon3, React as React5, util as util2 } from "pr1";
import { jsx as jsx7, jsxs as jsxs6 } from "react/jsx-runtime";
function Component6(props) {
  let [error, setError] = React5.useState(null);
  let pool = util2.usePool();
  React5.useEffect(() => {
    pool.add(async () => {
      let result = await window.api.hostSettings.createLocalHost(props.data.options);
      if (result.ok) {
        await props.queryHostSettings();
        props.setData({
          stepIndex: 2,
          hostSettingsId: result.hostSettingsId,
          label: props.data.options.label
        });
      } else {
        setError({ message: result.message });
      }
    });
  }, []);
  return /* @__PURE__ */ jsxs6("div", { className: "startup-editor-contents", children: [
    /* @__PURE__ */ jsxs6("div", { className: "startup-editor-inner", children: [
      /* @__PURE__ */ jsxs6("header", { className: "startup-editor-header", children: [
        /* @__PURE__ */ jsx7("div", { className: "startup-editor-subtitle", children: "New setup" }),
        /* @__PURE__ */ jsx7("h2", { children: "Set parameters" })
      ] }),
      error ? /* @__PURE__ */ jsxs6("div", { className: "startup-editor-status", children: [
        /* @__PURE__ */ jsx7(LargeIcon3, { name: "error" }),
        /* @__PURE__ */ jsx7("p", { children: error.message })
      ] }) : /* @__PURE__ */ jsx7("div", { className: "startup-editor-status", children: /* @__PURE__ */ jsx7("p", { children: "Loading" }) })
    ] }),
    /* @__PURE__ */ jsx7("div", { className: "startup-editor-action-root", children: /* @__PURE__ */ jsx7("div", { className: "startup-editor-action-list", children: /* @__PURE__ */ jsx7("button", { type: "button", disabled: !error, className: "startup-editor-action-item", onClick: () => {
      let installationSettings = props.data.options.pythonInstallationSettings;
      props.setData({
        stepIndex: 5,
        ...props.data.options,
        pythonInstallationSettings: {
          ...installationSettings,
          architecture: installationSettings.architecture ?? "_auto"
        }
      });
    }, children: "Back" }) }) })
  ] });
}

// src/startup/steps/s7.tsx
import { Pool, React as React6, Selector as Selector2 } from "pr1";
import { jsx as jsx8, jsxs as jsxs7 } from "react/jsx-runtime";
var Component7 = class extends React6.Component {
  controller = new AbortController();
  pool = new Pool();
  constructor(props) {
    super(props);
    this.state = {
      remoteHostInfos: null
    };
  }
  queryRemoteHostInfos() {
    this.pool.add(async () => {
      let remoteHostInfos = await window.api.hostSettings.queryRemoteHosts();
      if (this.controller.signal.aborted) {
        return;
      }
      this.setState({ remoteHostInfos });
      if (this.props.data.selectedHostIdentifier && !remoteHostInfos.some((hostInfo) => hostInfo.identifier === this.props.data.selectedHostIdentifier)) {
        this.props.setData({
          selectedHostIdentifier: null
        });
      }
    });
  }
  componentDidMount() {
    this.queryRemoteHostInfos();
  }
  componentWillUnmount() {
    this.controller.abort();
  }
  render() {
    return /* @__PURE__ */ jsxs7("form", { className: "startup-editor-contents", onSubmit: (event) => {
      event.preventDefault();
      this.props.setData({
        stepIndex: 1,
        options: this.state.remoteHostInfos.find((hostInfo) => {
          let bridge = hostInfo.bridges[0];
          return bridge.options.identifier === this.props.data.selectedHostIdentifier;
        }).bridges[0].options,
        previousStepData: this.props.data
      });
    }, children: [
      /* @__PURE__ */ jsxs7("div", { className: "startup-editor-inner", children: [
        /* @__PURE__ */ jsxs7("header", { className: "startup-editor-header", children: [
          /* @__PURE__ */ jsx8("div", { className: "startup-editor-subtitle", children: "New setup" }),
          /* @__PURE__ */ jsx8("h2", { children: "Search for setups on this network" })
        ] }),
        this.state.remoteHostInfos ? this.state.remoteHostInfos.length > 0 ? /* @__PURE__ */ jsx8(
          Selector2,
          {
            entries: this.state.remoteHostInfos.map((hostInfo) => {
              let bridge = hostInfo.bridges[0];
              let description;
              switch (bridge.type) {
                case "tcp":
                  description = `${bridge.options.hostname}:${bridge.options.port} (TCP with TLS)`;
                  break;
                default:
                  description = "Unknown";
              }
              return {
                id: hostInfo.identifier,
                name: hostInfo.description,
                description,
                icon: "router"
              };
            }),
            onSelect: (selectedHostIdentifier) => void this.props.setData({ selectedHostIdentifier }),
            selectedEntryId: this.props.data.selectedHostIdentifier
          }
        ) : /* @__PURE__ */ jsx8("div", { className: "startup-editor-status", children: /* @__PURE__ */ jsx8("p", { children: "No remote setup found." }) }) : /* @__PURE__ */ jsx8("div", { className: "startup-editor-status", children: /* @__PURE__ */ jsx8("p", { children: "Scanning..." }) })
      ] }),
      /* @__PURE__ */ jsxs7("div", { className: "startup-editor-action-root", children: [
        /* @__PURE__ */ jsx8("div", { className: "startup-editor-action-list", children: /* @__PURE__ */ jsx8("button", { type: "button", className: "startup-editor-action-item", onClick: () => {
          this.props.setData(this.props.data.previousStepData);
        }, children: "Back" }) }),
        /* @__PURE__ */ jsxs7("div", { className: "startup-editor-action-list", children: [
          /* @__PURE__ */ jsx8("button", { type: "button", className: "startup-editor-action-item", onClick: () => {
            this.queryRemoteHostInfos();
            this.setState({ remoteHostInfos: null });
          }, disabled: !this.state.remoteHostInfos, children: "Reload" }),
          /* @__PURE__ */ jsx8("button", { type: "submit", className: "startup-editor-action-item", disabled: !(this.state.remoteHostInfos && this.props.data.selectedHostIdentifier), children: "Next" })
        ] })
      ] })
    ] });
  }
};

// src/startup/host-creator.tsx
import { Fragment as Fragment3, jsx as jsx9 } from "react/jsx-runtime";
var HostCreator = class extends React7.Component {
  pool = new Pool2();
  constructor(props) {
    super(props);
    this.state = {
      context: null,
      data: {
        stepIndex: 4,
        mode: null
      }
    };
  }
  componentDidMount() {
    this.pool.add(async () => {
      let context = await window.api.hostSettings.getHostCreatorContext();
      this.setState({ context });
    });
  }
  render() {
    if (!this.state.context) {
      return /* @__PURE__ */ jsx9(Fragment3, {});
    }
    let Step = [
      Component,
      Component2,
      Component3,
      null,
      Component4,
      Component5,
      Component6,
      Component7
    ][this.state.data.stepIndex];
    return /* @__PURE__ */ jsx9(
      Step,
      {
        cancel: () => void this.props.close(),
        context: this.state.context,
        queryHostSettings: () => this.props.queryHostSettings(),
        data: this.state.data,
        setData: (update) => {
          this.setState((state) => {
            let data = typeof update === "function" ? update(state.data) : update;
            if (!data) {
              return null;
            }
            return {
              data: "stepIndex" in data ? data : { ...state.data, ...data }
            };
          });
        }
      }
    );
  }
};

// src/startup/renderer.tsx
import { jsx as jsx10 } from "react/jsx-runtime";
var App = class extends Component8 {
  pool = new Pool3();
  constructor(props) {
    super(props);
    this.state = {
      defaultHostSettingsId: null,
      hostSettingsRecord: null
    };
  }
  componentDidMount() {
    this.pool.add(async () => {
      await this.queryHostSettings();
      await document.fonts.load("12px Material Symbols Rounded");
      await document.fonts.load("12px Material Symbols Sharp");
      await document.fonts.load("12px Space Mono");
      window.api.main.ready();
    });
  }
  async queryHostSettings() {
    let { defaultHostSettingsId, hostSettingsRecord } = await window.api.hostSettings.list();
    this.setState({
      defaultHostSettingsId,
      hostSettingsRecord
    });
  }
  render() {
    if (!this.state.hostSettingsRecord) {
      return null;
    }
    return /* @__PURE__ */ jsx10(NativeContextMenuProvider, { children: /* @__PURE__ */ jsx10(
      Startup,
      {
        defaultHostInfoId: this.state.defaultHostSettingsId,
        hostInfos: Object.values(this.state.hostSettingsRecord).map((hostSettings) => ({
          id: hostSettings.id,
          description: hostSettings.options.type === "tcp" ? `${hostSettings.options.hostname}:${hostSettings.options.port}` : "Local",
          imageUrl: null,
          label: hostSettings.label,
          local: hostSettings.options.type === "local"
        })).sort(lib_default(function* (a, b, rules) {
          yield rules.text(a.label, b.label);
        })),
        deleteHostInfo: (hostInfoId) => {
          this.pool.add(async () => {
            await window.api.hostSettings.delete({ hostSettingsId: hostInfoId });
            await this.queryHostSettings();
          });
        },
        launchHostInfo: (hostInfoId) => {
          window.api.hostSettings.launchHost({ hostSettingsId: hostInfoId });
        },
        renderHostCreator: ({ close }) => /* @__PURE__ */ jsx10(
          HostCreator,
          {
            close,
            queryHostSettings: async () => void await this.queryHostSettings()
          }
        ),
        revealHostInfoLogsDirectory: (hostInfoId) => {
          window.api.hostSettings.revealLogsDirectory({ hostSettingsId: hostInfoId });
        },
        revealHostInfoSettingsDirectory: (hostInfoId) => {
          window.api.hostSettings.revealSettingsDirectory({ hostSettingsId: hostInfoId });
        },
        setDefaultHostInfo: (hostInfoId) => {
          this.pool.add(async () => {
            await window.api.hostSettings.setDefault({ hostSettingsId: hostInfoId });
            await this.queryHostSettings();
          });
        }
      }
    ) });
  }
};
document.body.dataset["platform"] = window.api.platform;
var root = createRoot(document.getElementById("root"));
root.render(/* @__PURE__ */ jsx10(App, {}));
export {
  App
};
